#
# spec file for package links
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           links
Version:        2.14
Release:        6.1
Summary:        Text-Based WWW Browser
License:        GPL-2.0+
Group:          Productivity/Networking/Web/Browsers
Url:            http://links.twibright.com/
Source:         http://links.twibright.com/download/%{name}-%{version}.tar.bz2
Patch2:         configure.diff
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gpm-devel
BuildRequires:  libjpeg-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(direct)
BuildRequires:  pkgconfig(directfb)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
Provides:       web_browser
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Links is like Lynx--an easy-to-use browser for HTML documents and other
Internet services, like FTP, telnet, and news. Links provides a
graphical interface besides the text interface. It has good support for
frames, supports ssl, and has a little bit of JavaScript support.

%prep
%setup -q
%patch2 -p1

%build
autoreconf -ifv
CFLAGS="%{optflags} -DOPENSSL_NO_SSL_INTERN"
%configure \
        --with-ipv6 \
        --with-zlib \
        --with-bzip2 \
        --with-lzma \
        --with-fb \
        --with-directfb \
        --with-libjpeg \
        --with-libtiff \
        --with-ssl \
        --with-x \
        --enable-graphics
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc README NEWS ChangeLog BRAILLE_HOWTO AUTHORS COPYING KEYS SITES
%doc doc/links_cal
%{_bindir}/links
%{_mandir}/man1/links.1.gz

%changelog
* Thu Jun 15 2017 astieger@suse.com
- links 2.14:
  * Limit keepalive of ciphers with 64-bit block size to mitigate
    the SWEET32 attack bsc#1022469
  * Report home directory in the "Version" window
  * Improved tor hardening
  * Use keys 'P' and 'L' to scroll up and down
  * Fix a memory leak when copying the current url to clipboard
  * Fix crash when the user pressed Ctrl-G on a form field
  * Workaround for a bug in librsvg that makes mathematics on
    Wikipedia unreadable
  * Support fourth and fifth mouse button in gpm and framebuffer
  * Fixed bugs when downgrading SSL connection while https proxy or
    socks proxy is used
  * Security bug fixed: Don't load or render the content of
    "407 Proxy Authentication Required" reply when using https
    proxy. This avoids the FalseCONNECT attack. bsc#1022468
    Also, don't allow 401 and 407 responses to set cookies.
  * Pop openssl error stack on every error - make sure that SSL
    errors on one connection do not affect other connections
  * Never select directfb driver automatically unless started with
    the '-driver directfb' option
- previously patched:
  * Disable SSL compression to avoid the CRIME attack bsc#1022469
    drop links-nosslcomp.patch
* Sat Aug  6 2016 astieger@suse.com
- links 2.13:
  * Page up and page down scroll slightly less than a page
  * Use domain list from publicsuffix.org to prevent setting
    cookies on public domains.
  * Fix bug that allowed bla.com to register cookie for la.com or a.com
  * Fixed a bug in the X driver that characters with unicode codes
    128-255 could not be entered with some locales
  * Security bug fixed: Use separate unix domain socket for anonymous
    instances, so that the anonymous instance won't connect to non-anonymous
    one [boo#992495]
  * <samp> element
  * In case of certification verification failure, don't pop up multiple
    dialog windows asking for the same server
  * Do not lookup .onion addresses directly, as specified by rfc7686
  * Updated Polish Translation
  * Security enhancement: Warn if the SSL/TLS method was downgraded
* Mon Sep 21 2015 tchvatal@suse.com
- Version bump to 2.12:
  * Verify ssl certificates bnc#946065
  * Warn if server uses SSL2 or SSL3 protocol
  * Support SSL client certificates
- Remove obsolete patch:
  * links-no-date-time.patch
- Rebase patch:
  * links-nosslcomp.patch
* Tue Jul 21 2015 astieger@suse.com
- update to 2.10:
  * SVG support using the rsvg library
  * Attach to existing links instance instead of creating a new
    instance
  * Detect image type based on the first few bytes rather than on
    content-type
  * Use OpenMP in the image scaler
  * Preallocate downloaded files on Linux
  * Support libevent and libev
  * SSL SNI no enabled upstream, remove links-sni.patch
  * Support keepalive on https connections
* Fri Dec 26 2014 tchvatal@suse.com
- Version bump to 2.9:
  * Work around some screen-corruption bugs in the OpenVMS terminal driver
  * Support mouse wheel in framebuffer (unfortunatelly we can't support it
    in text mode because when we instruct gpm to send us the wheel event,
    gpm stops drawing the cursor when the mouse is moved).
  * Pring "^" and "_" for <sub> and <sup> tags in text mode
  * An option to fake Firefox in the HTTP header. It modifies User-Agent and
    several other options to be more Firefox-like. This option is also
    automatically turned on when "Connect only via proxies or Socks (useful
    for tor)" is selected. It makes it safer to use Links with tor.
  * Fixed quadratic complexity in the text renderer when exteremely long
    lines were used
  * Do not print the character 0x9b if the display character set doesn't
    have it, because it is interpreted as a control character on the Linux
    console
  * An option to break long lines in <pre> sections
  * Consume less memory when 8-bit gamma correction is used
  * Updated the list of top level domains
  * Use malloc_trim to return unused memory to the system
  * Support RFC5987 for filenames
  * Support StaticColor in the X-window driver
  * Fix crash on OS/2 if image is wider than 10921 pixels
  * Use clock_gettime if available
  * The ability to set screen margins for text mode and framebuffer
  * Fix palette corruption on framebuffer when links instance was terminated
    while it was not active
  * Improve the gif decoder to accept more images
  * Increase the amount of data read from the socket, it improves speed when
    loading big images
  * Accept "text/xml" as html type
* Fri Dec 26 2014 tchvatal@suse.com
- Format with spec-cleaner
* Wed Oct  2 2013 andreas.stieger@gmx.de
- version 2.8
  * Fixed a memory leak if TIFF download was interrupted
  * Do not save lines starting with space to URL history on the disk
  * Do not misreport Date header value as last-modified date
    in the info box popping up on "=".
  * New graphics glyphs
  * Fixed file 045e.png. It was not compatible with libpng-1.6
  * Test integers addition for overflow. This fixes possible crashes
    due to overflows, they could possibly be security-sensitive.
  * Fixed a bug in Xwindow driver when images larger than 65536
    pixels were used
  * Fixed some integer overflows when scaling images larger than
    65536 pixels
  * Fixed invalid pointer comparison (comparing if NULL is smaller
    than non-NULL pointer) that could result in failures with certain
    compilers
  * Fixed an internal error in decompressed file cache if Links
    was running out of memory and was freeing cached data
  * An option that allows the user not to save URL history
  * An option to send do not track request
  * Reduced CPU consumption when downloading big files
  * Fixed a crash if the user selects "Save as" and the document has
    no header (the bug was introduced in Links 2.7pre1)
  * Parse FTP directories on VMS FTP server
  * Use a blocking pipe when communicating with the dns process, it
    fixes a possible error when system pipe buffer is too small
  * data: url
  * Accept color in #xxx format (besides usual #xxxxxx)
  * Fixed an infinite retry loop when the server terminates
    connection prematurely
  * Fixed some races in the framebuffer driver that could result in
    display corruption if the user is switching virtual consoles too
    quickly
  * Don't save URLs with password to history file on a disk
  * Fixed a rare bug where image alpha channel was not applied
    correctly
- package calibration pattern and other documentation files
- updated patches for upstream changes:
  * configure.diff
  * links-nosslcomp.patch
  * links-sni.patch
- support simultaneous build jobs
* Thu Aug 22 2013 crrodriguez@opensuse.org
- links-no-date-time.patch: Supress usage of __DATE__ and
  __TIME__ macros  build-compare should be happy now.
* Thu Aug 22 2013 crrodriguez@opensuse.org
- version 2.7
  * support ipv6
  * Fix memory leak in ftp
  * support HTTPS proxy
- Update spec file URL section.
- Fix buildRequires, add support for lzma and bzip2, just use
  pkgconfig(x11) instead of xorg-x11-devel
* Sun Jul 28 2013 crrodriguez@opensuse.org
- Silly me tried to connect to a HTTPS host that uses
  Server Name Indication (SNI) expecting it
  to do something sane, of course, it did not work.
  links-sni.patch: fix that.
* Mon Feb 11 2013 crrodriguez@opensuse.org
- Extend configure.diff so _GNU_SOURCE and largefile Support
  is tested properly
- expand inks-nosslcomp.patch to fix other misuses of the openssl
  API including TLSv1 being disabled (with the wrong API too)
- build with SSL_NO_INTERN so we can escape ABI breaks in future
  openSSL versions
* Mon Feb 11 2013 crrodriguez@opensuse.org
- links was used to demonstrate bnc#803004
  "openSSL 1.0.1d breaks most, if not all, SSL connections"
  It also turns out that links is not doing SSL stuff quite right..
  HTTPS clients must not negotiate SSL compression which is compromised
  since CVE-2012-4929 (aka. the CRIME attack) and should not even
  try to use SSLv2 either which is broken since a very long time
  (links-nosslcomp.patch)
* Tue May 15 2012 bg@suse.com
- updated to 2.6
  * Fixed integer overflows if file cache has more than 2GB
  * Continue downloads to partially downloaded file
  * Reload bookmarks if some other Links instance changes them
  * Fix for big endian Xserver
  * Fixed several inefficiencies
  * Lots more fixes, see ChangeLog
  * This also fixes bnc#756403
* Mon Jan 16 2012 pgajdos@suse.cz
- updated to 2.5
  * obsoletes libpng15.patch
  * Support lzma compression
  * Implemented forward history
  * Removed save bookmarks menu option, bookmarks are saved always when
    closing bookmark window
  * Recognise tgz extension
  * Do not send '#' in the url when downloading
  * etc, see ChangeLog
* Fri Jan  6 2012 pgajdos@suse.com
- build also for libpng15
  * libpng15.patch
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Sep 22 2010 cristian.rodriguez@opensuse.org
- Restore mssing mouse and tiff support
* Fri Aug  7 2009 bg@suse.de
- update to version 2.2
  - lots of bugfixes
  - Support HTTP/0.9
  - translation update for french and swiss german
  - also fixes bug #262302
  - for a detailed list, see http://links.twibright.com/download/ChangeLog
- remove javascript, because it is broken anyways.
* Sun Jun  1 2008 crrodriguez@suse.de
- needs fno-strict-aliasing
* Wed Aug 22 2007 bg@suse.de
- update to version 2.1pre30
  o Fixed security bug: special characters in URL could be passed to a
    shell when spawning user viewer
* Fri Aug 10 2007 bg@suse.de
- update to version 2.1pre29
  o several fixes
  o updates of translations
  o http://user:password@host/ possible now
  o Allowed download of files larger than 2G
  o Accept urls http://host.domain#position
  o Removed SDL support
  o readded javascript needed for blinux (was removed in this version)
* Fri Feb  9 2007 ro@suse.de
- fix build as non-root
* Fri Nov 17 2006 bg@suse.de
- disable smb protocol in url.c. Fix Bug #221645.
* Mon Oct 16 2006 ro@suse.de
- use DirectFB-devel in BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Thu Sep 22 2005 bg@suse.de
- update to version 2.1pre18
- fixing compiler warnings
* Mon Feb 28 2005 bg@suse.de
- update to version 2.1pre17
* Fri Feb  4 2005 bg@suse.de
- update to version 2.1pre16
- fixed compiler warnings
* Thu Jul 29 2004 bg@suse.de
- update to version 2.1pre15
* Tue Feb  3 2004 bg@suse.de
- fixed compiler warnings
* Fri Jan  9 2004 bg@suse.de
- update to version 2.1pre14
- enabled framebuffer
* Mon Jun  2 2003 bg@suse.de
- update to version 2.1pre11
- broken cookies (www.sueddeutsche.de) don't crash links anymore
- navigation with keyborad arrows now works in graphical mode as
  well.
* Wed Feb 12 2003 bg@suse.de
- update to version 2.1pre7
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Aug  6 2002 bg@suse.de
- update to version 2.1pre2
- added graphics support
* Mon Sep  3 2001 bg@suse.de
- update to version 0.96
- SSL connections are now possible
- lots of translation updates
* Thu Aug 24 2000 bg@suse.de
- new Version 0.92
- added patch for dummy java-script
- added patch for saving cookies
- added BuildRoot
* Tue May 30 2000 bg@suse.de
- initial release
